function fileList = getAllFiles(dirName)

  dirData = dir(dirName);      %# Get the data for the current directory
  dirIndex = [dirData.isdir];  %# Find the index for directories
  fileList = {dirData(~dirIndex).name}';  %'# Get a list of the files
  if ~isempty(fileList)
    fileList = cellfun(@(x) fullfile(dirName,x),...  %# Prepend path to files
                       fileList,'UniformOutput',false);
  end
  subDirs = {dirData(dirIndex).name};  %# Get a list of the subdirectories
  validIndex = ~ismember(subDirs,{'.','..'});  %# Find index of subdirectories
                                               %#   that are not '.' or '..'
  for iDir = find(validIndex)                  %# Loop over valid subdirectories
    nextDir = fullfile(dirName,subDirs{iDir});    %# Get the subdirectory path
    fileList = [fileList; getAllFiles(nextDir)];  %# Recursively call getAllFiles
  end

end


%%           
% I used the code mentioned in this great answer and expanded it to 
% support 2 additional parameters which I needed in my case. 
% The parameters are file extensions to filter on and a flag 
% indicating whether to concatenate the full path to the 
% name of the file or not.
% 
% I hope it is clear enough and someone will finds it beneficial.
% 
% function fileList = getAllFiles(dirName, fileExtension, appendFullPath)
% 
%   dirData = dir([dirName '/' fileExtension]);      %# Get the data for the current directory
%   dirWithSubFolders = dir(dirName);
%   dirIndex = [dirWithSubFolders.isdir];  %# Find the index for directories
%   fileList = {dirData.name}';  %'# Get a list of the files
%   if ~isempty(fileList)
%     if appendFullPath
%       fileList = cellfun(@(x) fullfile(dirName,x),...  %# Prepend path to files
%                        fileList,'UniformOutput',false);
%     end
%   end
%   subDirs = {dirWithSubFolders(dirIndex).name};  %# Get a list of the subdirectories
%   validIndex = ~ismember(subDirs,{'.','..'});  %# Find index of subdirectories
%                                                %#   that are not '.' or '..'
%   for iDir = find(validIndex)                  %# Loop over valid subdirectories
%     nextDir = fullfile(dirName,subDirs{iDir});    %# Get the subdirectory path
%     fileList = [fileList; getAllFiles(nextDir, fileExtension, appendFullPath)];  %# Recursively call getAllFiles
%   end
% 
% end
% Example for running the code:

